@@ -2,12 +2,14 @@ use strict;
 use warnings;
 package A1z::HTML5::Template;
 
+use vars qw(%ENV);
+
 # ABSTRACT: Fast/easy Web Apps in Perl
 
 
 sub NAME { my $self = shift; my $NAME; $NAME = "Fast and Easy Web Apps"; return $NAME; }
 
-our $VERSION = '0.18';
+our $VERSION = '0.19';
 
 
 
@@ -1142,7 +1144,7 @@ sub head
 		-jqueryui 	=> html_jqueryui_css, 
 		-htmlshim	=> html_shim_respond, 
 		-humanejs  => html_humanejs_css, 
-		-title 		=> "A1z.us", 
+		-title 		=> "$ENV{SERVER_NAME}", 
 		-cssLinks => "https://code.jquery.com/ui/1.11.4/themes/ui-lightness/jquery-ui.css,https://blueimp.github.io/Gallery/css/blueimp-gallery.min.css,https://www.a1z.us/A1z/HTML5/Template.css", 
 		-cssCode => "", 
 		-mobilemeta => qq{<meta name="HandheldFriendly" content="true">
@@ -1154,12 +1156,7 @@ sub head
 		@_,
 		
 	); 
-	
-	for (keys %in) 
-	{
-		chomp $in{"$_"};
-		
-	}
+
 
 # rotating title function and text 
 my $setTitle;
@@ -1172,7 +1169,7 @@ if ( $in{-titleRotatingText} and $in{-titleRotatingText} =~ /\,/ )
 }
 else
 {
-	$setTitle = html_setTitle(ta => "Text01", tb => "text02" tc => "text03");
+	$setTitle = html_setTitle(ta => "Text01", tb => "text02", tc => "text03");
 }
 
 # css multiple links/files 
@@ -1244,7 +1241,7 @@ sub body
 		-defaultjquery => qq{$HTML{-defaultjquery}}, 
 		-humanejs => qq{<script src="https://cdnjs.cloudflare.com/ajax/libs/humane-js/3.2.2/humane.min.js">},
 		-userjquery => qq{}, 
-		-navbar => html_navbar( $in{-nbmenu}, $in{-nbpage}, " ") , 
+		-navbar => html_navbar( $in{-nbmenu}, $in{-nbpage}, "", ""), 
 		-content => qq{<div class="content">Content</div>}, 
 		-footer => qq{All rights reserved &copy; $ENV{SERVER_NAME}}, 	
 		-bootstrapbluimp => html_bootstrap_bluimp,
@@ -1875,7 +1872,7 @@ A1z::HTML5::Template - Fast/easy Web Apps in Perl
 
 =head1 VERSION
 
-version 0.18
+version 0.19
 
 =head1 SYNOPSIS
 
@@ -1951,7 +1948,7 @@ version 0.18
 
 =head2 VERSION
 
-	0.18
+	0.19
 
 =head1 Installation
 
